@@ -9,14 +9,10 @@ This is the complete API reference:
 .. autosummary::
    :toctree: .
 
-   Biometa
-   DObjectBiometa
    Biosample
    Techsample
-   BiosampleTechsample
    Readout
    Treatment
-   ProjectExperiment
    Experiment
    ExperimentType
 
@@ -26,22 +22,21 @@ Development tools:
    :toctree: .
 
    dev
+   link
 
 """
 # This is lnschema-module vvhc.
 _schema_id = "vvhc"
 _name = "wetlab"
 _migration = "bfda12fc80a8"
-__version__ = "0.8.1"
+__version__ = "0.10.2"
 
-from ._biosample import Biosample
+from . import dev, link
 from ._core import (  # noqa
-    Biometa,
-    DObjectBiometa,
+    Biosample,
     Experiment,
     ExperimentType,
-    ProjectExperiment,
     Readout,
+    Techsample,
     Treatment,
 )
-from ._techsample import BiosampleTechsample, Techsample
